# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HistoricFPNCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'promoter_swa_code': 'str',
        'highway_authority_swa_code': 'str',
        'works_coordinates': 'object',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'usrn': 'float',
        'road_category': 'float',
        'historical_permit_reference': 'str',
        'works_location_description': 'str',
        'description_of_work': 'str',
        'work_start_date': 'datetime',
        'work_end_date': 'datetime',
        'fpn_evidence': 'bool',
        'file_ids': 'list[float]',
        'offence_date': 'datetime',
        'offence_code': 'OffenceCode',
        'offence_details': 'str',
        'authorised_officer': 'str',
        'officer_contact_details': 'str',
        'officer_address': 'str',
        'representations_contact': 'str',
        'representations_contact_address': 'str',
        'payment_methods': 'list[PaymentMethod]'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'promoter_swa_code': 'promoter_swa_code',
        'highway_authority_swa_code': 'highway_authority_swa_code',
        'works_coordinates': 'works_coordinates',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'usrn': 'usrn',
        'road_category': 'road_category',
        'historical_permit_reference': 'historical_permit_reference',
        'works_location_description': 'works_location_description',
        'description_of_work': 'description_of_work',
        'work_start_date': 'work_start_date',
        'work_end_date': 'work_end_date',
        'fpn_evidence': 'fpn_evidence',
        'file_ids': 'file_ids',
        'offence_date': 'offence_date',
        'offence_code': 'offence_code',
        'offence_details': 'offence_details',
        'authorised_officer': 'authorised_officer',
        'officer_contact_details': 'officer_contact_details',
        'officer_address': 'officer_address',
        'representations_contact': 'representations_contact',
        'representations_contact_address': 'representations_contact_address',
        'payment_methods': 'payment_methods'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, promoter_swa_code=None, highway_authority_swa_code=None, works_coordinates=None, street_name=None, town=None, area_name=None, usrn=None, road_category=None, historical_permit_reference=None, works_location_description=None, description_of_work=None, work_start_date=None, work_end_date=None, fpn_evidence=None, file_ids=None, offence_date=None, offence_code=None, offence_details=None, authorised_officer=None, officer_contact_details=None, officer_address=None, representations_contact=None, representations_contact_address=None, payment_methods=None):  # noqa: E501
        """HistoricFPNCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._promoter_swa_code = None
        self._highway_authority_swa_code = None
        self._works_coordinates = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._usrn = None
        self._road_category = None
        self._historical_permit_reference = None
        self._works_location_description = None
        self._description_of_work = None
        self._work_start_date = None
        self._work_end_date = None
        self._fpn_evidence = None
        self._file_ids = None
        self._offence_date = None
        self._offence_code = None
        self._offence_details = None
        self._authorised_officer = None
        self._officer_contact_details = None
        self._officer_address = None
        self._representations_contact = None
        self._representations_contact_address = None
        self._payment_methods = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.promoter_swa_code = promoter_swa_code
        self.highway_authority_swa_code = highway_authority_swa_code
        self.works_coordinates = works_coordinates
        if street_name is not None:
            self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        self.usrn = usrn
        if road_category is not None:
            self.road_category = road_category
        self.historical_permit_reference = historical_permit_reference
        self.works_location_description = works_location_description
        if description_of_work is not None:
            self.description_of_work = description_of_work
        if work_start_date is not None:
            self.work_start_date = work_start_date
        if work_end_date is not None:
            self.work_end_date = work_end_date
        self.fpn_evidence = fpn_evidence
        if file_ids is not None:
            self.file_ids = file_ids
        self.offence_date = offence_date
        self.offence_code = offence_code
        self.offence_details = offence_details
        self.authorised_officer = authorised_officer
        self.officer_contact_details = officer_contact_details
        self.officer_address = officer_address
        self.representations_contact = representations_contact
        self.representations_contact_address = representations_contact_address
        self.payment_methods = payment_methods

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this HistoricFPNCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this HistoricFPNCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def promoter_swa_code(self):
        """Gets the promoter_swa_code of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 4 characters  # noqa: E501

        :return: The promoter_swa_code of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._promoter_swa_code

    @promoter_swa_code.setter
    def promoter_swa_code(self, promoter_swa_code):
        """Sets the promoter_swa_code of this HistoricFPNCreateRequest.

        Max length 4 characters  # noqa: E501

        :param promoter_swa_code: The promoter_swa_code of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """
        if promoter_swa_code is None:
            raise ValueError("Invalid value for `promoter_swa_code`, must not be `None`")  # noqa: E501

        self._promoter_swa_code = promoter_swa_code

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 4 characters  # noqa: E501

        :return: The highway_authority_swa_code of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this HistoricFPNCreateRequest.

        Max length 4 characters  # noqa: E501

        :param highway_authority_swa_code: The highway_authority_swa_code of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    @property
    def works_coordinates(self):
        """Gets the works_coordinates of this HistoricFPNCreateRequest.  # noqa: E501

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :return: The works_coordinates of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: object
        """
        return self._works_coordinates

    @works_coordinates.setter
    def works_coordinates(self, works_coordinates):
        """Sets the works_coordinates of this HistoricFPNCreateRequest.

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :param works_coordinates: The works_coordinates of this HistoricFPNCreateRequest.  # noqa: E501
        :type: object
        """
        if works_coordinates is None:
            raise ValueError("Invalid value for `works_coordinates`, must not be `None`")  # noqa: E501

        self._works_coordinates = works_coordinates

    @property
    def street_name(self):
        """Gets the street_name of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The street_name of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this HistoricFPNCreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param street_name: The street_name of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The town of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this HistoricFPNCreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param town: The town of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The area_name of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this HistoricFPNCreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param area_name: The area_name of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def usrn(self):
        """Gets the usrn of this HistoricFPNCreateRequest.  # noqa: E501

        Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN  # noqa: E501

        :return: The usrn of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this HistoricFPNCreateRequest.

        Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN  # noqa: E501

        :param usrn: The usrn of this HistoricFPNCreateRequest.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def road_category(self):
        """Gets the road_category of this HistoricFPNCreateRequest.  # noqa: E501

        Is whole number between 0 and 10 inclusive If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The road_category of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._road_category

    @road_category.setter
    def road_category(self, road_category):
        """Sets the road_category of this HistoricFPNCreateRequest.

        Is whole number between 0 and 10 inclusive If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param road_category: The road_category of this HistoricFPNCreateRequest.  # noqa: E501
        :type: float
        """

        self._road_category = road_category

    @property
    def historical_permit_reference(self):
        """Gets the historical_permit_reference of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 24 characters Must be unique in the system, this will become the work_reference_number Must contain only alphanumeric characters, dashes and underscores  # noqa: E501

        :return: The historical_permit_reference of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._historical_permit_reference

    @historical_permit_reference.setter
    def historical_permit_reference(self, historical_permit_reference):
        """Sets the historical_permit_reference of this HistoricFPNCreateRequest.

        Max length 24 characters Must be unique in the system, this will become the work_reference_number Must contain only alphanumeric characters, dashes and underscores  # noqa: E501

        :param historical_permit_reference: The historical_permit_reference of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """
        if historical_permit_reference is None:
            raise ValueError("Invalid value for `historical_permit_reference`, must not be `None`")  # noqa: E501

        self._historical_permit_reference = historical_permit_reference

    @property
    def works_location_description(self):
        """Gets the works_location_description of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The works_location_description of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._works_location_description

    @works_location_description.setter
    def works_location_description(self, works_location_description):
        """Sets the works_location_description of this HistoricFPNCreateRequest.

        Max length 500 characters  # noqa: E501

        :param works_location_description: The works_location_description of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """
        if works_location_description is None:
            raise ValueError("Invalid value for `works_location_description`, must not be `None`")  # noqa: E501

        self._works_location_description = works_location_description

    @property
    def description_of_work(self):
        """Gets the description_of_work of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The description_of_work of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description_of_work

    @description_of_work.setter
    def description_of_work(self, description_of_work):
        """Sets the description_of_work of this HistoricFPNCreateRequest.

        Max length 500 characters  # noqa: E501

        :param description_of_work: The description_of_work of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """

        self._description_of_work = description_of_work

    @property
    def work_start_date(self):
        """Gets the work_start_date of this HistoricFPNCreateRequest.  # noqa: E501

        Date must be in the past  # noqa: E501

        :return: The work_start_date of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._work_start_date

    @work_start_date.setter
    def work_start_date(self, work_start_date):
        """Sets the work_start_date of this HistoricFPNCreateRequest.

        Date must be in the past  # noqa: E501

        :param work_start_date: The work_start_date of this HistoricFPNCreateRequest.  # noqa: E501
        :type: datetime
        """

        self._work_start_date = work_start_date

    @property
    def work_end_date(self):
        """Gets the work_end_date of this HistoricFPNCreateRequest.  # noqa: E501

        Date must be in the past work_end_date must be after the date and time for work_start_date  # noqa: E501

        :return: The work_end_date of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._work_end_date

    @work_end_date.setter
    def work_end_date(self, work_end_date):
        """Sets the work_end_date of this HistoricFPNCreateRequest.

        Date must be in the past work_end_date must be after the date and time for work_start_date  # noqa: E501

        :param work_end_date: The work_end_date of this HistoricFPNCreateRequest.  # noqa: E501
        :type: datetime
        """

        self._work_end_date = work_end_date

    @property
    def fpn_evidence(self):
        """Gets the fpn_evidence of this HistoricFPNCreateRequest.  # noqa: E501

        Whether FPN evidence has been supplied  # noqa: E501

        :return: The fpn_evidence of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._fpn_evidence

    @fpn_evidence.setter
    def fpn_evidence(self, fpn_evidence):
        """Sets the fpn_evidence of this HistoricFPNCreateRequest.

        Whether FPN evidence has been supplied  # noqa: E501

        :param fpn_evidence: The fpn_evidence of this HistoricFPNCreateRequest.  # noqa: E501
        :type: bool
        """
        if fpn_evidence is None:
            raise ValueError("Invalid value for `fpn_evidence`, must not be `None`")  # noqa: E501

        self._fpn_evidence = fpn_evidence

    @property
    def file_ids(self):
        """Gets the file_ids of this HistoricFPNCreateRequest.  # noqa: E501

        Required if fpn_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :return: The file_ids of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._file_ids

    @file_ids.setter
    def file_ids(self, file_ids):
        """Sets the file_ids of this HistoricFPNCreateRequest.

        Required if fpn_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :param file_ids: The file_ids of this HistoricFPNCreateRequest.  # noqa: E501
        :type: list[float]
        """

        self._file_ids = file_ids

    @property
    def offence_date(self):
        """Gets the offence_date of this HistoricFPNCreateRequest.  # noqa: E501

        offence_date must be in the past  # noqa: E501

        :return: The offence_date of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._offence_date

    @offence_date.setter
    def offence_date(self, offence_date):
        """Sets the offence_date of this HistoricFPNCreateRequest.

        offence_date must be in the past  # noqa: E501

        :param offence_date: The offence_date of this HistoricFPNCreateRequest.  # noqa: E501
        :type: datetime
        """
        if offence_date is None:
            raise ValueError("Invalid value for `offence_date`, must not be `None`")  # noqa: E501

        self._offence_date = offence_date

    @property
    def offence_code(self):
        """Gets the offence_code of this HistoricFPNCreateRequest.  # noqa: E501


        :return: The offence_code of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: OffenceCode
        """
        return self._offence_code

    @offence_code.setter
    def offence_code(self, offence_code):
        """Sets the offence_code of this HistoricFPNCreateRequest.


        :param offence_code: The offence_code of this HistoricFPNCreateRequest.  # noqa: E501
        :type: OffenceCode
        """
        if offence_code is None:
            raise ValueError("Invalid value for `offence_code`, must not be `None`")  # noqa: E501

        self._offence_code = offence_code

    @property
    def offence_details(self):
        """Gets the offence_details of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The offence_details of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._offence_details

    @offence_details.setter
    def offence_details(self, offence_details):
        """Sets the offence_details of this HistoricFPNCreateRequest.

        Max length 500 characters  # noqa: E501

        :param offence_details: The offence_details of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """
        if offence_details is None:
            raise ValueError("Invalid value for `offence_details`, must not be `None`")  # noqa: E501

        self._offence_details = offence_details

    @property
    def authorised_officer(self):
        """Gets the authorised_officer of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The authorised_officer of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._authorised_officer

    @authorised_officer.setter
    def authorised_officer(self, authorised_officer):
        """Sets the authorised_officer of this HistoricFPNCreateRequest.

        Max length 100 characters  # noqa: E501

        :param authorised_officer: The authorised_officer of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """
        if authorised_officer is None:
            raise ValueError("Invalid value for `authorised_officer`, must not be `None`")  # noqa: E501

        self._authorised_officer = authorised_officer

    @property
    def officer_contact_details(self):
        """Gets the officer_contact_details of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The officer_contact_details of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._officer_contact_details

    @officer_contact_details.setter
    def officer_contact_details(self, officer_contact_details):
        """Sets the officer_contact_details of this HistoricFPNCreateRequest.

        Max length 100 characters  # noqa: E501

        :param officer_contact_details: The officer_contact_details of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """
        if officer_contact_details is None:
            raise ValueError("Invalid value for `officer_contact_details`, must not be `None`")  # noqa: E501

        self._officer_contact_details = officer_contact_details

    @property
    def officer_address(self):
        """Gets the officer_address of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The officer_address of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._officer_address

    @officer_address.setter
    def officer_address(self, officer_address):
        """Sets the officer_address of this HistoricFPNCreateRequest.

        Max length 500 characters  # noqa: E501

        :param officer_address: The officer_address of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """
        if officer_address is None:
            raise ValueError("Invalid value for `officer_address`, must not be `None`")  # noqa: E501

        self._officer_address = officer_address

    @property
    def representations_contact(self):
        """Gets the representations_contact of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The representations_contact of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._representations_contact

    @representations_contact.setter
    def representations_contact(self, representations_contact):
        """Sets the representations_contact of this HistoricFPNCreateRequest.

        Max length 100 characters  # noqa: E501

        :param representations_contact: The representations_contact of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """
        if representations_contact is None:
            raise ValueError("Invalid value for `representations_contact`, must not be `None`")  # noqa: E501

        self._representations_contact = representations_contact

    @property
    def representations_contact_address(self):
        """Gets the representations_contact_address of this HistoricFPNCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The representations_contact_address of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._representations_contact_address

    @representations_contact_address.setter
    def representations_contact_address(self, representations_contact_address):
        """Sets the representations_contact_address of this HistoricFPNCreateRequest.

        Max length 500 characters  # noqa: E501

        :param representations_contact_address: The representations_contact_address of this HistoricFPNCreateRequest.  # noqa: E501
        :type: str
        """
        if representations_contact_address is None:
            raise ValueError("Invalid value for `representations_contact_address`, must not be `None`")  # noqa: E501

        self._representations_contact_address = representations_contact_address

    @property
    def payment_methods(self):
        """Gets the payment_methods of this HistoricFPNCreateRequest.  # noqa: E501


        :return: The payment_methods of this HistoricFPNCreateRequest.  # noqa: E501
        :rtype: list[PaymentMethod]
        """
        return self._payment_methods

    @payment_methods.setter
    def payment_methods(self, payment_methods):
        """Sets the payment_methods of this HistoricFPNCreateRequest.


        :param payment_methods: The payment_methods of this HistoricFPNCreateRequest.  # noqa: E501
        :type: list[PaymentMethod]
        """
        if payment_methods is None:
            raise ValueError("Invalid value for `payment_methods`, must not be `None`")  # noqa: E501

        self._payment_methods = payment_methods

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HistoricFPNCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoricFPNCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager GeoJSON API

    See API specification Resource Guide > GeoJSON API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ..api_client import ApiClient


class DefaultApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_activities_intersecting_bounds(self, min_easting, min_northing, max_easting, max_northing, **kwargs):  # noqa: E501
        """get_activities_intersecting_bounds  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get activities endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activities_intersecting_bounds(min_easting, min_northing, max_easting, max_northing, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param datetime start_date:
        :param datetime end_date:
        :return: ActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activities_intersecting_bounds_with_http_info(min_easting, min_northing, max_easting, max_northing, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activities_intersecting_bounds_with_http_info(min_easting, min_northing, max_easting, max_northing, **kwargs)  # noqa: E501
            return data

    def get_activities_intersecting_bounds_with_http_info(self, min_easting, min_northing, max_easting, max_northing, **kwargs):  # noqa: E501
        """get_activities_intersecting_bounds  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get activities endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activities_intersecting_bounds_with_http_info(min_easting, min_northing, max_easting, max_northing, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param datetime start_date:
        :param datetime end_date:
        :return: ActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['min_easting', 'min_northing', 'max_easting', 'max_northing', 'start_date', 'end_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activities_intersecting_bounds" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'min_easting' is set
        if ('min_easting' not in params or
                params['min_easting'] is None):
            raise ValueError("Missing the required parameter `min_easting` when calling `get_activities_intersecting_bounds`")  # noqa: E501
        # verify the required parameter 'min_northing' is set
        if ('min_northing' not in params or
                params['min_northing'] is None):
            raise ValueError("Missing the required parameter `min_northing` when calling `get_activities_intersecting_bounds`")  # noqa: E501
        # verify the required parameter 'max_easting' is set
        if ('max_easting' not in params or
                params['max_easting'] is None):
            raise ValueError("Missing the required parameter `max_easting` when calling `get_activities_intersecting_bounds`")  # noqa: E501
        # verify the required parameter 'max_northing' is set
        if ('max_northing' not in params or
                params['max_northing'] is None):
            raise ValueError("Missing the required parameter `max_northing` when calling `get_activities_intersecting_bounds`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'min_easting' in params:
            query_params.append(('minEasting', params['min_easting']))  # noqa: E501
        if 'min_northing' in params:
            query_params.append(('minNorthing', params['min_northing']))  # noqa: E501
        if 'max_easting' in params:
            query_params.append(('maxEasting', params['max_easting']))  # noqa: E501
        if 'max_northing' in params:
            query_params.append(('maxNorthing', params['max_northing']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('start_date', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/activities', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ancillary_information_intersect_bounding_box(self, min_easting, min_northing, max_easting, max_northing, **kwargs):  # noqa: E501
        """get_ancillary_information_intersect_bounding_box  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get AncillaryInformations endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ancillary_information_intersect_bounding_box(min_easting, min_northing, max_easting, max_northing, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param datetime start_date:
        :param datetime end_date:
        :param str ancillary_info_reference_number:
        :return: AncillaryInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ancillary_information_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ancillary_information_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, **kwargs)  # noqa: E501
            return data

    def get_ancillary_information_intersect_bounding_box_with_http_info(self, min_easting, min_northing, max_easting, max_northing, **kwargs):  # noqa: E501
        """get_ancillary_information_intersect_bounding_box  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get AncillaryInformations endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ancillary_information_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param datetime start_date:
        :param datetime end_date:
        :param str ancillary_info_reference_number:
        :return: AncillaryInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['min_easting', 'min_northing', 'max_easting', 'max_northing', 'start_date', 'end_date', 'ancillary_info_reference_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ancillary_information_intersect_bounding_box" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'min_easting' is set
        if ('min_easting' not in params or
                params['min_easting'] is None):
            raise ValueError("Missing the required parameter `min_easting` when calling `get_ancillary_information_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'min_northing' is set
        if ('min_northing' not in params or
                params['min_northing'] is None):
            raise ValueError("Missing the required parameter `min_northing` when calling `get_ancillary_information_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'max_easting' is set
        if ('max_easting' not in params or
                params['max_easting'] is None):
            raise ValueError("Missing the required parameter `max_easting` when calling `get_ancillary_information_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'max_northing' is set
        if ('max_northing' not in params or
                params['max_northing'] is None):
            raise ValueError("Missing the required parameter `max_northing` when calling `get_ancillary_information_intersect_bounding_box`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'min_easting' in params:
            query_params.append(('minEasting', params['min_easting']))  # noqa: E501
        if 'min_northing' in params:
            query_params.append(('minNorthing', params['min_northing']))  # noqa: E501
        if 'max_easting' in params:
            query_params.append(('maxEasting', params['max_easting']))  # noqa: E501
        if 'max_northing' in params:
            query_params.append(('maxNorthing', params['max_northing']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('start_date', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501
        if 'ancillary_info_reference_number' in params:
            query_params.append(('ancillary_info_reference_number', params['ancillary_info_reference_number']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/ancillary-informations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AncillaryInfoResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_forward_plans_intersect_bounding_box(self, min_easting, min_northing, max_easting, max_northing, **kwargs):  # noqa: E501
        """get_forward_plans_intersect_bounding_box  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get ForwardPlans endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_forward_plans_intersect_bounding_box(min_easting, min_northing, max_easting, max_northing, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param datetime start_date:
        :param datetime end_date:
        :param str forward_plan_reference_number:
        :return: ForwardPlanResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_forward_plans_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, **kwargs)  # noqa: E501
        else:
            (data) = self.get_forward_plans_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, **kwargs)  # noqa: E501
            return data

    def get_forward_plans_intersect_bounding_box_with_http_info(self, min_easting, min_northing, max_easting, max_northing, **kwargs):  # noqa: E501
        """get_forward_plans_intersect_bounding_box  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get ForwardPlans endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_forward_plans_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param datetime start_date:
        :param datetime end_date:
        :param str forward_plan_reference_number:
        :return: ForwardPlanResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['min_easting', 'min_northing', 'max_easting', 'max_northing', 'start_date', 'end_date', 'forward_plan_reference_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_forward_plans_intersect_bounding_box" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'min_easting' is set
        if ('min_easting' not in params or
                params['min_easting'] is None):
            raise ValueError("Missing the required parameter `min_easting` when calling `get_forward_plans_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'min_northing' is set
        if ('min_northing' not in params or
                params['min_northing'] is None):
            raise ValueError("Missing the required parameter `min_northing` when calling `get_forward_plans_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'max_easting' is set
        if ('max_easting' not in params or
                params['max_easting'] is None):
            raise ValueError("Missing the required parameter `max_easting` when calling `get_forward_plans_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'max_northing' is set
        if ('max_northing' not in params or
                params['max_northing'] is None):
            raise ValueError("Missing the required parameter `max_northing` when calling `get_forward_plans_intersect_bounding_box`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'min_easting' in params:
            query_params.append(('minEasting', params['min_easting']))  # noqa: E501
        if 'min_northing' in params:
            query_params.append(('minNorthing', params['min_northing']))  # noqa: E501
        if 'max_easting' in params:
            query_params.append(('maxEasting', params['max_easting']))  # noqa: E501
        if 'max_northing' in params:
            query_params.append(('maxNorthing', params['max_northing']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('start_date', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501
        if 'forward_plan_reference_number' in params:
            query_params.append(('forward_plan_reference_number', params['forward_plan_reference_number']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/forward-plans', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ForwardPlanResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_hs2_act_limits_intersecting_bounds(self, min_easting, min_northing, max_easting, max_northing, phase, **kwargs):  # noqa: E501
        """get_hs2_act_limits_intersecting_bounds  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get Hs2ActLimits endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_hs2_act_limits_intersecting_bounds(min_easting, min_northing, max_easting, max_northing, phase, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param Hs2ActLimitPhase phase: (required)
        :return: Hs2ActLimitsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_hs2_act_limits_intersecting_bounds_with_http_info(min_easting, min_northing, max_easting, max_northing, phase, **kwargs)  # noqa: E501
        else:
            (data) = self.get_hs2_act_limits_intersecting_bounds_with_http_info(min_easting, min_northing, max_easting, max_northing, phase, **kwargs)  # noqa: E501
            return data

    def get_hs2_act_limits_intersecting_bounds_with_http_info(self, min_easting, min_northing, max_easting, max_northing, phase, **kwargs):  # noqa: E501
        """get_hs2_act_limits_intersecting_bounds  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get Hs2ActLimits endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_hs2_act_limits_intersecting_bounds_with_http_info(min_easting, min_northing, max_easting, max_northing, phase, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param Hs2ActLimitPhase phase: (required)
        :return: Hs2ActLimitsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['min_easting', 'min_northing', 'max_easting', 'max_northing', 'phase']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_hs2_act_limits_intersecting_bounds" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'min_easting' is set
        if ('min_easting' not in params or
                params['min_easting'] is None):
            raise ValueError("Missing the required parameter `min_easting` when calling `get_hs2_act_limits_intersecting_bounds`")  # noqa: E501
        # verify the required parameter 'min_northing' is set
        if ('min_northing' not in params or
                params['min_northing'] is None):
            raise ValueError("Missing the required parameter `min_northing` when calling `get_hs2_act_limits_intersecting_bounds`")  # noqa: E501
        # verify the required parameter 'max_easting' is set
        if ('max_easting' not in params or
                params['max_easting'] is None):
            raise ValueError("Missing the required parameter `max_easting` when calling `get_hs2_act_limits_intersecting_bounds`")  # noqa: E501
        # verify the required parameter 'max_northing' is set
        if ('max_northing' not in params or
                params['max_northing'] is None):
            raise ValueError("Missing the required parameter `max_northing` when calling `get_hs2_act_limits_intersecting_bounds`")  # noqa: E501
        # verify the required parameter 'phase' is set
        if ('phase' not in params or
                params['phase'] is None):
            raise ValueError("Missing the required parameter `phase` when calling `get_hs2_act_limits_intersecting_bounds`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'min_easting' in params:
            query_params.append(('minEasting', params['min_easting']))  # noqa: E501
        if 'min_northing' in params:
            query_params.append(('minNorthing', params['min_northing']))  # noqa: E501
        if 'max_easting' in params:
            query_params.append(('maxEasting', params['max_easting']))  # noqa: E501
        if 'max_northing' in params:
            query_params.append(('maxNorthing', params['max_northing']))  # noqa: E501
        if 'phase' in params:
            query_params.append(('phase', params['phase']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/hs2-act-limits', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Hs2ActLimitsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_material_classifications_intersect_bounding_box(self, **kwargs):  # noqa: E501
        """get_material_classifications_intersect_bounding_box  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get Material Classifications endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_material_classifications_intersect_bounding_box(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting:
        :param float min_northing:
        :param float max_easting:
        :param float max_northing:
        :param datetime sample_date_from:
        :param datetime sample_date_to:
        :param float usrn:
        :param MaterialClassificationClassification classification:
        :return: MaterialClassificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_material_classifications_intersect_bounding_box_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_material_classifications_intersect_bounding_box_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_material_classifications_intersect_bounding_box_with_http_info(self, **kwargs):  # noqa: E501
        """get_material_classifications_intersect_bounding_box  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get Material Classifications endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_material_classifications_intersect_bounding_box_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting:
        :param float min_northing:
        :param float max_easting:
        :param float max_northing:
        :param datetime sample_date_from:
        :param datetime sample_date_to:
        :param float usrn:
        :param MaterialClassificationClassification classification:
        :return: MaterialClassificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['min_easting', 'min_northing', 'max_easting', 'max_northing', 'sample_date_from', 'sample_date_to', 'usrn', 'classification']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_material_classifications_intersect_bounding_box" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'min_easting' in params:
            query_params.append(('minEasting', params['min_easting']))  # noqa: E501
        if 'min_northing' in params:
            query_params.append(('minNorthing', params['min_northing']))  # noqa: E501
        if 'max_easting' in params:
            query_params.append(('maxEasting', params['max_easting']))  # noqa: E501
        if 'max_northing' in params:
            query_params.append(('maxNorthing', params['max_northing']))  # noqa: E501
        if 'sample_date_from' in params:
            query_params.append(('sample_date_from', params['sample_date_from']))  # noqa: E501
        if 'sample_date_to' in params:
            query_params.append(('sample_date_to', params['sample_date_to']))  # noqa: E501
        if 'usrn' in params:
            query_params.append(('usrn', params['usrn']))  # noqa: E501
        if 'classification' in params:
            query_params.append(('classification', params['classification']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/material-classifications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MaterialClassificationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_section58s_intersect_bounding_box(self, min_easting, min_northing, max_easting, max_northing, **kwargs):  # noqa: E501
        """get_section58s_intersect_bounding_box  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get Section 58s endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_section58s_intersect_bounding_box(min_easting, min_northing, max_easting, max_northing, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param datetime start_date:
        :param datetime end_date:
        :param str section_58_reference_number:
        :return: Section58Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_section58s_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, **kwargs)  # noqa: E501
        else:
            (data) = self.get_section58s_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, **kwargs)  # noqa: E501
            return data

    def get_section58s_intersect_bounding_box_with_http_info(self, min_easting, min_northing, max_easting, max_northing, **kwargs):  # noqa: E501
        """get_section58s_intersect_bounding_box  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get Section 58s endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_section58s_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param datetime start_date:
        :param datetime end_date:
        :param str section_58_reference_number:
        :return: Section58Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['min_easting', 'min_northing', 'max_easting', 'max_northing', 'start_date', 'end_date', 'section_58_reference_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_section58s_intersect_bounding_box" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'min_easting' is set
        if ('min_easting' not in params or
                params['min_easting'] is None):
            raise ValueError("Missing the required parameter `min_easting` when calling `get_section58s_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'min_northing' is set
        if ('min_northing' not in params or
                params['min_northing'] is None):
            raise ValueError("Missing the required parameter `min_northing` when calling `get_section58s_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'max_easting' is set
        if ('max_easting' not in params or
                params['max_easting'] is None):
            raise ValueError("Missing the required parameter `max_easting` when calling `get_section58s_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'max_northing' is set
        if ('max_northing' not in params or
                params['max_northing'] is None):
            raise ValueError("Missing the required parameter `max_northing` when calling `get_section58s_intersect_bounding_box`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'min_easting' in params:
            query_params.append(('minEasting', params['min_easting']))  # noqa: E501
        if 'min_northing' in params:
            query_params.append(('minNorthing', params['min_northing']))  # noqa: E501
        if 'max_easting' in params:
            query_params.append(('maxEasting', params['max_easting']))  # noqa: E501
        if 'max_northing' in params:
            query_params.append(('maxNorthing', params['max_northing']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('start_date', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501
        if 'section_58_reference_number' in params:
            query_params.append(('section_58_reference_number', params['section_58_reference_number']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/section-58s', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Section58Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_works_intersect_bounding_box(self, min_easting, min_northing, max_easting, max_northing, **kwargs):  # noqa: E501
        """get_works_intersect_bounding_box  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get works endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_works_intersect_bounding_box(min_easting, min_northing, max_easting, max_northing, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param datetime start_date:
        :param datetime end_date:
        :param str work_reference_number:
        :return: WorkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_works_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, **kwargs)  # noqa: E501
        else:
            (data) = self.get_works_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, **kwargs)  # noqa: E501
            return data

    def get_works_intersect_bounding_box_with_http_info(self, min_easting, min_northing, max_easting, max_northing, **kwargs):  # noqa: E501
        """get_works_intersect_bounding_box  # noqa: E501

        See API specification Resource Guide > GeoJSON API > Get works endpoint for more information Authenticated user must have one of the following roles: Planner, Contractor, HighwayAuthority  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_works_intersect_bounding_box_with_http_info(min_easting, min_northing, max_easting, max_northing, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float min_easting: (required)
        :param float min_northing: (required)
        :param float max_easting: (required)
        :param float max_northing: (required)
        :param datetime start_date:
        :param datetime end_date:
        :param str work_reference_number:
        :return: WorkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['min_easting', 'min_northing', 'max_easting', 'max_northing', 'start_date', 'end_date', 'work_reference_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_works_intersect_bounding_box" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'min_easting' is set
        if ('min_easting' not in params or
                params['min_easting'] is None):
            raise ValueError("Missing the required parameter `min_easting` when calling `get_works_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'min_northing' is set
        if ('min_northing' not in params or
                params['min_northing'] is None):
            raise ValueError("Missing the required parameter `min_northing` when calling `get_works_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'max_easting' is set
        if ('max_easting' not in params or
                params['max_easting'] is None):
            raise ValueError("Missing the required parameter `max_easting` when calling `get_works_intersect_bounding_box`")  # noqa: E501
        # verify the required parameter 'max_northing' is set
        if ('max_northing' not in params or
                params['max_northing'] is None):
            raise ValueError("Missing the required parameter `max_northing` when calling `get_works_intersect_bounding_box`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'min_easting' in params:
            query_params.append(('minEasting', params['min_easting']))  # noqa: E501
        if 'min_northing' in params:
            query_params.append(('minNorthing', params['min_northing']))  # noqa: E501
        if 'max_easting' in params:
            query_params.append(('maxEasting', params['max_easting']))  # noqa: E501
        if 'max_northing' in params:
            query_params.append(('maxNorthing', params['max_northing']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('start_date', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501
        if 'work_reference_number' in params:
            query_params.append(('work_reference_number', params['work_reference_number']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token']  # noqa: E501

        return self.api_client.call_api(
            '/works', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



#!/usr/bin/env python3
"""
Test script to verify that swagger client imports are working correctly.
This script will:
1. Try to import various modules from the swagger client
2. Create instances of some model classes
3. Print success/failure for each test
"""

import sys
from pathlib import Path

# Add the src directory to the Python path
src_path = Path(__file__).parent.parent / 'src'
sys.path.append(str(src_path))

def test_import(module_path, class_name=None):
    """Test importing a module and optionally a class from it."""
    try:
        module = __import__(module_path, fromlist=[class_name] if class_name else None)
        if class_name:
            class_obj = getattr(module, class_name)
            print(f"✅ Successfully imported {module_path}.{class_name}")
            return True
        else:
            print(f"✅ Successfully imported {module_path}")
            return True
    except Exception as e:
        print(f"❌ Failed to import {module_path}{f'.{class_name}' if class_name else ''}: {str(e)}")
        return False

def main():
    """Run all import tests."""
    print("Testing swagger client imports...\n")
    
    # Test importing the main swagger client module
    test_import('streetmanager.work.swagger_client')
    
    # Test importing some model classes
    test_import('streetmanager.work.swagger_client.models', 'LaneRentalAssessmentChargeBand')
    test_import('streetmanager.work.swagger_client.models', 'PermitResponse')
    test_import('streetmanager.work.swagger_client.models', 'WorkResponse')
    
    # Test importing some "all_of" classes that use relative imports
    test_import('streetmanager.work.swagger_client.models.all_of_permit_lane_rental_assessment_update_request_charge_band',
                'AllOfPermitLaneRentalAssessmentUpdateRequestChargeBand')
    test_import('streetmanager.work.swagger_client.models.all_of_inspection_summary_response_inspection_outcome',
                'AllOfInspectionSummaryResponseInspectionOutcome')
    
    # Test importing the API client
    test_import('streetmanager.work.swagger_client.api_client', 'ApiClient')
    
    # Test importing the default API
    test_import('streetmanager.work.swagger_client.api.default_api', 'DefaultApi')

if __name__ == '__main__':
    main() 


# coding: utf-8

"""
    Street Manager Street Lookup API

    See API specification Resource Guide > Street Lookup API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StreetResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'usrn': 'float',
        'street_descriptor': 'str',
        'area': 'str',
        'town': 'str',
        'authority': 'str',
        'authority_swa_code': 'str',
        'road_category': 'float',
        'reinstatement_types': 'list[ReinstatementTypeDetails]',
        'traffic_sensitive': 'bool',
        'primary_notice_authorities': 'list[PrimaryNoticeAuthority]',
        'interest_authorities': 'list[InterestAuthority]',
        'additional_special_designations_response': 'list[AdditionalSpecialDesignationsResponse]',
        'street_line': 'AllOfStreetResponseStreetLine',
        'street_centre_point': 'AllOfStreetResponseStreetCentrePoint'
    }

    attribute_map = {
        'usrn': 'usrn',
        'street_descriptor': 'street_descriptor',
        'area': 'area',
        'town': 'town',
        'authority': 'authority',
        'authority_swa_code': 'authority_swa_code',
        'road_category': 'road_category',
        'reinstatement_types': 'reinstatement_types',
        'traffic_sensitive': 'traffic_sensitive',
        'primary_notice_authorities': 'primary_notice_authorities',
        'interest_authorities': 'interest_authorities',
        'additional_special_designations_response': 'additional_special_designations_response',
        'street_line': 'street_line',
        'street_centre_point': 'street_centre_point'
    }

    def __init__(self, usrn=None, street_descriptor=None, area=None, town=None, authority=None, authority_swa_code=None, road_category=None, reinstatement_types=None, traffic_sensitive=None, primary_notice_authorities=None, interest_authorities=None, additional_special_designations_response=None, street_line=None, street_centre_point=None):  # noqa: E501
        """StreetResponse - a model defined in Swagger"""  # noqa: E501
        self._usrn = None
        self._street_descriptor = None
        self._area = None
        self._town = None
        self._authority = None
        self._authority_swa_code = None
        self._road_category = None
        self._reinstatement_types = None
        self._traffic_sensitive = None
        self._primary_notice_authorities = None
        self._interest_authorities = None
        self._additional_special_designations_response = None
        self._street_line = None
        self._street_centre_point = None
        self.discriminator = None
        self.usrn = usrn
        self.street_descriptor = street_descriptor
        self.area = area
        self.town = town
        self.authority = authority
        self.authority_swa_code = authority_swa_code
        self.road_category = road_category
        self.reinstatement_types = reinstatement_types
        self.traffic_sensitive = traffic_sensitive
        self.primary_notice_authorities = primary_notice_authorities
        self.interest_authorities = interest_authorities
        self.additional_special_designations_response = additional_special_designations_response
        if street_line is not None:
            self.street_line = street_line
        if street_centre_point is not None:
            self.street_centre_point = street_centre_point

    @property
    def usrn(self):
        """Gets the usrn of this StreetResponse.  # noqa: E501


        :return: The usrn of this StreetResponse.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this StreetResponse.


        :param usrn: The usrn of this StreetResponse.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def street_descriptor(self):
        """Gets the street_descriptor of this StreetResponse.  # noqa: E501


        :return: The street_descriptor of this StreetResponse.  # noqa: E501
        :rtype: str
        """
        return self._street_descriptor

    @street_descriptor.setter
    def street_descriptor(self, street_descriptor):
        """Sets the street_descriptor of this StreetResponse.


        :param street_descriptor: The street_descriptor of this StreetResponse.  # noqa: E501
        :type: str
        """
        if street_descriptor is None:
            raise ValueError("Invalid value for `street_descriptor`, must not be `None`")  # noqa: E501

        self._street_descriptor = street_descriptor

    @property
    def area(self):
        """Gets the area of this StreetResponse.  # noqa: E501


        :return: The area of this StreetResponse.  # noqa: E501
        :rtype: str
        """
        return self._area

    @area.setter
    def area(self, area):
        """Sets the area of this StreetResponse.


        :param area: The area of this StreetResponse.  # noqa: E501
        :type: str
        """
        if area is None:
            raise ValueError("Invalid value for `area`, must not be `None`")  # noqa: E501

        self._area = area

    @property
    def town(self):
        """Gets the town of this StreetResponse.  # noqa: E501


        :return: The town of this StreetResponse.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this StreetResponse.


        :param town: The town of this StreetResponse.  # noqa: E501
        :type: str
        """
        if town is None:
            raise ValueError("Invalid value for `town`, must not be `None`")  # noqa: E501

        self._town = town

    @property
    def authority(self):
        """Gets the authority of this StreetResponse.  # noqa: E501


        :return: The authority of this StreetResponse.  # noqa: E501
        :rtype: str
        """
        return self._authority

    @authority.setter
    def authority(self, authority):
        """Sets the authority of this StreetResponse.


        :param authority: The authority of this StreetResponse.  # noqa: E501
        :type: str
        """
        if authority is None:
            raise ValueError("Invalid value for `authority`, must not be `None`")  # noqa: E501

        self._authority = authority

    @property
    def authority_swa_code(self):
        """Gets the authority_swa_code of this StreetResponse.  # noqa: E501


        :return: The authority_swa_code of this StreetResponse.  # noqa: E501
        :rtype: str
        """
        return self._authority_swa_code

    @authority_swa_code.setter
    def authority_swa_code(self, authority_swa_code):
        """Sets the authority_swa_code of this StreetResponse.


        :param authority_swa_code: The authority_swa_code of this StreetResponse.  # noqa: E501
        :type: str
        """
        if authority_swa_code is None:
            raise ValueError("Invalid value for `authority_swa_code`, must not be `None`")  # noqa: E501

        self._authority_swa_code = authority_swa_code

    @property
    def road_category(self):
        """Gets the road_category of this StreetResponse.  # noqa: E501

        DEPRECATED  # noqa: E501

        :return: The road_category of this StreetResponse.  # noqa: E501
        :rtype: float
        """
        return self._road_category

    @road_category.setter
    def road_category(self, road_category):
        """Sets the road_category of this StreetResponse.

        DEPRECATED  # noqa: E501

        :param road_category: The road_category of this StreetResponse.  # noqa: E501
        :type: float
        """
        if road_category is None:
            raise ValueError("Invalid value for `road_category`, must not be `None`")  # noqa: E501

        self._road_category = road_category

    @property
    def reinstatement_types(self):
        """Gets the reinstatement_types of this StreetResponse.  # noqa: E501


        :return: The reinstatement_types of this StreetResponse.  # noqa: E501
        :rtype: list[ReinstatementTypeDetails]
        """
        return self._reinstatement_types

    @reinstatement_types.setter
    def reinstatement_types(self, reinstatement_types):
        """Sets the reinstatement_types of this StreetResponse.


        :param reinstatement_types: The reinstatement_types of this StreetResponse.  # noqa: E501
        :type: list[ReinstatementTypeDetails]
        """
        if reinstatement_types is None:
            raise ValueError("Invalid value for `reinstatement_types`, must not be `None`")  # noqa: E501

        self._reinstatement_types = reinstatement_types

    @property
    def traffic_sensitive(self):
        """Gets the traffic_sensitive of this StreetResponse.  # noqa: E501


        :return: The traffic_sensitive of this StreetResponse.  # noqa: E501
        :rtype: bool
        """
        return self._traffic_sensitive

    @traffic_sensitive.setter
    def traffic_sensitive(self, traffic_sensitive):
        """Sets the traffic_sensitive of this StreetResponse.


        :param traffic_sensitive: The traffic_sensitive of this StreetResponse.  # noqa: E501
        :type: bool
        """
        if traffic_sensitive is None:
            raise ValueError("Invalid value for `traffic_sensitive`, must not be `None`")  # noqa: E501

        self._traffic_sensitive = traffic_sensitive

    @property
    def primary_notice_authorities(self):
        """Gets the primary_notice_authorities of this StreetResponse.  # noqa: E501


        :return: The primary_notice_authorities of this StreetResponse.  # noqa: E501
        :rtype: list[PrimaryNoticeAuthority]
        """
        return self._primary_notice_authorities

    @primary_notice_authorities.setter
    def primary_notice_authorities(self, primary_notice_authorities):
        """Sets the primary_notice_authorities of this StreetResponse.


        :param primary_notice_authorities: The primary_notice_authorities of this StreetResponse.  # noqa: E501
        :type: list[PrimaryNoticeAuthority]
        """
        if primary_notice_authorities is None:
            raise ValueError("Invalid value for `primary_notice_authorities`, must not be `None`")  # noqa: E501

        self._primary_notice_authorities = primary_notice_authorities

    @property
    def interest_authorities(self):
        """Gets the interest_authorities of this StreetResponse.  # noqa: E501


        :return: The interest_authorities of this StreetResponse.  # noqa: E501
        :rtype: list[InterestAuthority]
        """
        return self._interest_authorities

    @interest_authorities.setter
    def interest_authorities(self, interest_authorities):
        """Sets the interest_authorities of this StreetResponse.


        :param interest_authorities: The interest_authorities of this StreetResponse.  # noqa: E501
        :type: list[InterestAuthority]
        """
        if interest_authorities is None:
            raise ValueError("Invalid value for `interest_authorities`, must not be `None`")  # noqa: E501

        self._interest_authorities = interest_authorities

    @property
    def additional_special_designations_response(self):
        """Gets the additional_special_designations_response of this StreetResponse.  # noqa: E501


        :return: The additional_special_designations_response of this StreetResponse.  # noqa: E501
        :rtype: list[AdditionalSpecialDesignationsResponse]
        """
        return self._additional_special_designations_response

    @additional_special_designations_response.setter
    def additional_special_designations_response(self, additional_special_designations_response):
        """Sets the additional_special_designations_response of this StreetResponse.


        :param additional_special_designations_response: The additional_special_designations_response of this StreetResponse.  # noqa: E501
        :type: list[AdditionalSpecialDesignationsResponse]
        """
        if additional_special_designations_response is None:
            raise ValueError("Invalid value for `additional_special_designations_response`, must not be `None`")  # noqa: E501

        self._additional_special_designations_response = additional_special_designations_response

    @property
    def street_line(self):
        """Gets the street_line of this StreetResponse.  # noqa: E501


        :return: The street_line of this StreetResponse.  # noqa: E501
        :rtype: AllOfStreetResponseStreetLine
        """
        return self._street_line

    @street_line.setter
    def street_line(self, street_line):
        """Sets the street_line of this StreetResponse.


        :param street_line: The street_line of this StreetResponse.  # noqa: E501
        :type: AllOfStreetResponseStreetLine
        """

        self._street_line = street_line

    @property
    def street_centre_point(self):
        """Gets the street_centre_point of this StreetResponse.  # noqa: E501


        :return: The street_centre_point of this StreetResponse.  # noqa: E501
        :rtype: AllOfStreetResponseStreetCentrePoint
        """
        return self._street_centre_point

    @street_centre_point.setter
    def street_centre_point(self, street_centre_point):
        """Sets the street_centre_point of this StreetResponse.


        :param street_centre_point: The street_centre_point of this StreetResponse.  # noqa: E501
        :type: AllOfStreetResponseStreetCentrePoint
        """

        self._street_centre_point = street_centre_point

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StreetResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager GeoJSON API

    See API specification Resource Guide > GeoJSON API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AncillaryInfoProperties(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'work_reference_number': 'str',
        'permit_reference_number': 'str',
        'ancillary_info_reference_number': 'str',
        'location_description': 'str',
        'ancillary_info_type': 'AncillaryInfoTypeResponse',
        'ancillary_info_status': 'AncillaryInfoStatusResponse',
        'ancillary_info_type_string': 'str',
        'ancillary_info_status_string': 'str',
        'ancillary_info_centre_point': 'GeoJSONCentrePoint',
        'ancillary_info_coordinates': 'list[object]',
        'promoter_organisation': 'str',
        'date_created': 'datetime',
        'usrns': 'list[float]'
    }

    attribute_map = {
        'work_reference_number': 'work_reference_number',
        'permit_reference_number': 'permit_reference_number',
        'ancillary_info_reference_number': 'ancillary_info_reference_number',
        'location_description': 'location_description',
        'ancillary_info_type': 'ancillary_info_type',
        'ancillary_info_status': 'ancillary_info_status',
        'ancillary_info_type_string': 'ancillary_info_type_string',
        'ancillary_info_status_string': 'ancillary_info_status_string',
        'ancillary_info_centre_point': 'ancillary_info_centre_point',
        'ancillary_info_coordinates': 'ancillary_info_coordinates',
        'promoter_organisation': 'promoter_organisation',
        'date_created': 'date_created',
        'usrns': 'usrns'
    }

    def __init__(self, work_reference_number=None, permit_reference_number=None, ancillary_info_reference_number=None, location_description=None, ancillary_info_type=None, ancillary_info_status=None, ancillary_info_type_string=None, ancillary_info_status_string=None, ancillary_info_centre_point=None, ancillary_info_coordinates=None, promoter_organisation=None, date_created=None, usrns=None):  # noqa: E501
        """AncillaryInfoProperties - a model defined in Swagger"""  # noqa: E501
        self._work_reference_number = None
        self._permit_reference_number = None
        self._ancillary_info_reference_number = None
        self._location_description = None
        self._ancillary_info_type = None
        self._ancillary_info_status = None
        self._ancillary_info_type_string = None
        self._ancillary_info_status_string = None
        self._ancillary_info_centre_point = None
        self._ancillary_info_coordinates = None
        self._promoter_organisation = None
        self._date_created = None
        self._usrns = None
        self.discriminator = None
        if work_reference_number is not None:
            self.work_reference_number = work_reference_number
        if permit_reference_number is not None:
            self.permit_reference_number = permit_reference_number
        self.ancillary_info_reference_number = ancillary_info_reference_number
        self.location_description = location_description
        self.ancillary_info_type = ancillary_info_type
        self.ancillary_info_status = ancillary_info_status
        self.ancillary_info_type_string = ancillary_info_type_string
        self.ancillary_info_status_string = ancillary_info_status_string
        self.ancillary_info_centre_point = ancillary_info_centre_point
        self.ancillary_info_coordinates = ancillary_info_coordinates
        self.promoter_organisation = promoter_organisation
        self.date_created = date_created
        self.usrns = usrns

    @property
    def work_reference_number(self):
        """Gets the work_reference_number of this AncillaryInfoProperties.  # noqa: E501


        :return: The work_reference_number of this AncillaryInfoProperties.  # noqa: E501
        :rtype: str
        """
        return self._work_reference_number

    @work_reference_number.setter
    def work_reference_number(self, work_reference_number):
        """Sets the work_reference_number of this AncillaryInfoProperties.


        :param work_reference_number: The work_reference_number of this AncillaryInfoProperties.  # noqa: E501
        :type: str
        """

        self._work_reference_number = work_reference_number

    @property
    def permit_reference_number(self):
        """Gets the permit_reference_number of this AncillaryInfoProperties.  # noqa: E501


        :return: The permit_reference_number of this AncillaryInfoProperties.  # noqa: E501
        :rtype: str
        """
        return self._permit_reference_number

    @permit_reference_number.setter
    def permit_reference_number(self, permit_reference_number):
        """Sets the permit_reference_number of this AncillaryInfoProperties.


        :param permit_reference_number: The permit_reference_number of this AncillaryInfoProperties.  # noqa: E501
        :type: str
        """

        self._permit_reference_number = permit_reference_number

    @property
    def ancillary_info_reference_number(self):
        """Gets the ancillary_info_reference_number of this AncillaryInfoProperties.  # noqa: E501


        :return: The ancillary_info_reference_number of this AncillaryInfoProperties.  # noqa: E501
        :rtype: str
        """
        return self._ancillary_info_reference_number

    @ancillary_info_reference_number.setter
    def ancillary_info_reference_number(self, ancillary_info_reference_number):
        """Sets the ancillary_info_reference_number of this AncillaryInfoProperties.


        :param ancillary_info_reference_number: The ancillary_info_reference_number of this AncillaryInfoProperties.  # noqa: E501
        :type: str
        """
        if ancillary_info_reference_number is None:
            raise ValueError("Invalid value for `ancillary_info_reference_number`, must not be `None`")  # noqa: E501

        self._ancillary_info_reference_number = ancillary_info_reference_number

    @property
    def location_description(self):
        """Gets the location_description of this AncillaryInfoProperties.  # noqa: E501


        :return: The location_description of this AncillaryInfoProperties.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this AncillaryInfoProperties.


        :param location_description: The location_description of this AncillaryInfoProperties.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    @property
    def ancillary_info_type(self):
        """Gets the ancillary_info_type of this AncillaryInfoProperties.  # noqa: E501


        :return: The ancillary_info_type of this AncillaryInfoProperties.  # noqa: E501
        :rtype: AncillaryInfoTypeResponse
        """
        return self._ancillary_info_type

    @ancillary_info_type.setter
    def ancillary_info_type(self, ancillary_info_type):
        """Sets the ancillary_info_type of this AncillaryInfoProperties.


        :param ancillary_info_type: The ancillary_info_type of this AncillaryInfoProperties.  # noqa: E501
        :type: AncillaryInfoTypeResponse
        """
        if ancillary_info_type is None:
            raise ValueError("Invalid value for `ancillary_info_type`, must not be `None`")  # noqa: E501

        self._ancillary_info_type = ancillary_info_type

    @property
    def ancillary_info_status(self):
        """Gets the ancillary_info_status of this AncillaryInfoProperties.  # noqa: E501


        :return: The ancillary_info_status of this AncillaryInfoProperties.  # noqa: E501
        :rtype: AncillaryInfoStatusResponse
        """
        return self._ancillary_info_status

    @ancillary_info_status.setter
    def ancillary_info_status(self, ancillary_info_status):
        """Sets the ancillary_info_status of this AncillaryInfoProperties.


        :param ancillary_info_status: The ancillary_info_status of this AncillaryInfoProperties.  # noqa: E501
        :type: AncillaryInfoStatusResponse
        """
        if ancillary_info_status is None:
            raise ValueError("Invalid value for `ancillary_info_status`, must not be `None`")  # noqa: E501

        self._ancillary_info_status = ancillary_info_status

    @property
    def ancillary_info_type_string(self):
        """Gets the ancillary_info_type_string of this AncillaryInfoProperties.  # noqa: E501


        :return: The ancillary_info_type_string of this AncillaryInfoProperties.  # noqa: E501
        :rtype: str
        """
        return self._ancillary_info_type_string

    @ancillary_info_type_string.setter
    def ancillary_info_type_string(self, ancillary_info_type_string):
        """Sets the ancillary_info_type_string of this AncillaryInfoProperties.


        :param ancillary_info_type_string: The ancillary_info_type_string of this AncillaryInfoProperties.  # noqa: E501
        :type: str
        """
        if ancillary_info_type_string is None:
            raise ValueError("Invalid value for `ancillary_info_type_string`, must not be `None`")  # noqa: E501

        self._ancillary_info_type_string = ancillary_info_type_string

    @property
    def ancillary_info_status_string(self):
        """Gets the ancillary_info_status_string of this AncillaryInfoProperties.  # noqa: E501


        :return: The ancillary_info_status_string of this AncillaryInfoProperties.  # noqa: E501
        :rtype: str
        """
        return self._ancillary_info_status_string

    @ancillary_info_status_string.setter
    def ancillary_info_status_string(self, ancillary_info_status_string):
        """Sets the ancillary_info_status_string of this AncillaryInfoProperties.


        :param ancillary_info_status_string: The ancillary_info_status_string of this AncillaryInfoProperties.  # noqa: E501
        :type: str
        """
        if ancillary_info_status_string is None:
            raise ValueError("Invalid value for `ancillary_info_status_string`, must not be `None`")  # noqa: E501

        self._ancillary_info_status_string = ancillary_info_status_string

    @property
    def ancillary_info_centre_point(self):
        """Gets the ancillary_info_centre_point of this AncillaryInfoProperties.  # noqa: E501


        :return: The ancillary_info_centre_point of this AncillaryInfoProperties.  # noqa: E501
        :rtype: GeoJSONCentrePoint
        """
        return self._ancillary_info_centre_point

    @ancillary_info_centre_point.setter
    def ancillary_info_centre_point(self, ancillary_info_centre_point):
        """Sets the ancillary_info_centre_point of this AncillaryInfoProperties.


        :param ancillary_info_centre_point: The ancillary_info_centre_point of this AncillaryInfoProperties.  # noqa: E501
        :type: GeoJSONCentrePoint
        """
        if ancillary_info_centre_point is None:
            raise ValueError("Invalid value for `ancillary_info_centre_point`, must not be `None`")  # noqa: E501

        self._ancillary_info_centre_point = ancillary_info_centre_point

    @property
    def ancillary_info_coordinates(self):
        """Gets the ancillary_info_coordinates of this AncillaryInfoProperties.  # noqa: E501


        :return: The ancillary_info_coordinates of this AncillaryInfoProperties.  # noqa: E501
        :rtype: list[object]
        """
        return self._ancillary_info_coordinates

    @ancillary_info_coordinates.setter
    def ancillary_info_coordinates(self, ancillary_info_coordinates):
        """Sets the ancillary_info_coordinates of this AncillaryInfoProperties.


        :param ancillary_info_coordinates: The ancillary_info_coordinates of this AncillaryInfoProperties.  # noqa: E501
        :type: list[object]
        """
        if ancillary_info_coordinates is None:
            raise ValueError("Invalid value for `ancillary_info_coordinates`, must not be `None`")  # noqa: E501

        self._ancillary_info_coordinates = ancillary_info_coordinates

    @property
    def promoter_organisation(self):
        """Gets the promoter_organisation of this AncillaryInfoProperties.  # noqa: E501


        :return: The promoter_organisation of this AncillaryInfoProperties.  # noqa: E501
        :rtype: str
        """
        return self._promoter_organisation

    @promoter_organisation.setter
    def promoter_organisation(self, promoter_organisation):
        """Sets the promoter_organisation of this AncillaryInfoProperties.


        :param promoter_organisation: The promoter_organisation of this AncillaryInfoProperties.  # noqa: E501
        :type: str
        """
        if promoter_organisation is None:
            raise ValueError("Invalid value for `promoter_organisation`, must not be `None`")  # noqa: E501

        self._promoter_organisation = promoter_organisation

    @property
    def date_created(self):
        """Gets the date_created of this AncillaryInfoProperties.  # noqa: E501


        :return: The date_created of this AncillaryInfoProperties.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this AncillaryInfoProperties.


        :param date_created: The date_created of this AncillaryInfoProperties.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def usrns(self):
        """Gets the usrns of this AncillaryInfoProperties.  # noqa: E501


        :return: The usrns of this AncillaryInfoProperties.  # noqa: E501
        :rtype: list[float]
        """
        return self._usrns

    @usrns.setter
    def usrns(self, usrns):
        """Sets the usrns of this AncillaryInfoProperties.


        :param usrns: The usrns of this AncillaryInfoProperties.  # noqa: E501
        :type: list[float]
        """
        if usrns is None:
            raise ValueError("Invalid value for `usrns`, must not be `None`")  # noqa: E501

        self._usrns = usrns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AncillaryInfoProperties, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AncillaryInfoProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.default_api import DefaultApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_acknowledge_hs2_permit(self):
        """Test case for acknowledge_hs2_permit

        """
        pass

    def test_add_file_to_work(self):
        """Test case for add_file_to_work

        """
        pass

    def test_authenticate(self):
        """Test case for authenticate

        """
        pass

    def test_calculate_duration(self):
        """Test case for calculate_duration

        """
        pass

    def test_cancel_activity(self):
        """Test case for cancel_activity

        """
        pass

    def test_cancel_forward_plan(self):
        """Test case for cancel_forward_plan

        """
        pass

    def test_cancel_private_street_notice(self):
        """Test case for cancel_private_street_notice

        """
        pass

    def test_create_activity(self):
        """Test case for create_activity

        """
        pass

    def test_create_ancillary_info(self):
        """Test case for create_ancillary_info

        """
        pass

    def test_create_forward_plan(self):
        """Test case for create_forward_plan

        """
        pass

    def test_create_fpn(self):
        """Test case for create_fpn

        """
        pass

    def test_create_geographical_area(self):
        """Test case for create_geographical_area

        """
        pass

    def test_create_historic_fpn(self):
        """Test case for create_historic_fpn

        """
        pass

    def test_create_historic_inspection(self):
        """Test case for create_historic_inspection

        """
        pass

    def test_create_inspection(self):
        """Test case for create_inspection

        """
        pass

    def test_create_materials_classification(self):
        """Test case for create_materials_classification

        """
        pass

    def test_create_non_notifiable_site(self):
        """Test case for create_non_notifiable_site

        """
        pass

    def test_create_permit(self):
        """Test case for create_permit

        """
        pass

    def test_create_permit_alteration(self):
        """Test case for create_permit_alteration

        """
        pass

    def test_create_private_street_notice(self):
        """Test case for create_private_street_notice

        """
        pass

    def test_create_reinstatement(self):
        """Test case for create_reinstatement

        """
        pass

    def test_create_scheduled_inspection(self):
        """Test case for create_scheduled_inspection

        """
        pass

    def test_create_section58(self):
        """Test case for create_section58

        """
        pass

    def test_create_section74(self):
        """Test case for create_section74

        """
        pass

    def test_create_section81(self):
        """Test case for create_section81

        """
        pass

    def test_create_site(self):
        """Test case for create_site

        """
        pass

    def test_create_work(self):
        """Test case for create_work

        """
        pass

    def test_delete_file(self):
        """Test case for delete_file

        """
        pass

    def test_delete_fpn(self):
        """Test case for delete_fpn

        """
        pass

    def test_delete_inspection(self):
        """Test case for delete_inspection

        """
        pass

    def test_delete_reinstatement(self):
        """Test case for delete_reinstatement

        """
        pass

    def test_delete_scheduled_inspection(self):
        """Test case for delete_scheduled_inspection

        """
        pass

    def test_duration_challenge_non_acceptance_response(self):
        """Test case for duration_challenge_non_acceptance_response

        """
        pass

    def test_duration_challenge_review(self):
        """Test case for duration_challenge_review

        """
        pass

    def test_get_activity(self):
        """Test case for get_activity

        """
        pass

    def test_get_ancillary_info(self):
        """Test case for get_ancillary_info

        """
        pass

    def test_get_comment(self):
        """Test case for get_comment

        """
        pass

    def test_get_earliest_permit(self):
        """Test case for get_earliest_permit

        """
        pass

    def test_get_fee_matrix(self):
        """Test case for get_fee_matrix

        """
        pass

    def test_get_file(self):
        """Test case for get_file

        """
        pass

    def test_get_forward_plan(self):
        """Test case for get_forward_plan

        """
        pass

    def test_get_fpn(self):
        """Test case for get_fpn

        """
        pass

    def test_get_inspection(self):
        """Test case for get_inspection

        """
        pass

    def test_get_material_classification(self):
        """Test case for get_material_classification

        """
        pass

    def test_get_non_compliance(self):
        """Test case for get_non_compliance

        """
        pass

    def test_get_permit(self):
        """Test case for get_permit

        """
        pass

    def test_get_permit_alteration(self):
        """Test case for get_permit_alteration

        """
        pass

    def test_get_private_street_notice(self):
        """Test case for get_private_street_notice

        """
        pass

    def test_get_section58(self):
        """Test case for get_section58

        """
        pass

    def test_get_section74(self):
        """Test case for get_section74

        """
        pass

    def test_get_section81(self):
        """Test case for get_section81

        """
        pass

    def test_get_site(self):
        """Test case for get_site

        """
        pass

    def test_get_work(self):
        """Test case for get_work

        """
        pass

    def test_get_work_category(self):
        """Test case for get_work_category

        """
        pass

    def test_get_work_history(self):
        """Test case for get_work_history

        """
        pass

    def test_impose_change(self):
        """Test case for impose_change

        """
        pass

    def test_link_permit_to_non_compliance(self):
        """Test case for link_permit_to_non_compliance

        """
        pass

    def test_link_section81_to_permit(self):
        """Test case for link_section81_to_permit

        """
        pass

    def test_mark_comment_as_read(self):
        """Test case for mark_comment_as_read

        """
        pass

    def test_mark_permit_as_under_assessment(self):
        """Test case for mark_permit_as_under_assessment

        """
        pass

    def test_post_comment(self):
        """Test case for post_comment

        """
        pass

    def test_reassign_section81(self):
        """Test case for reassign_section81

        """
        pass

    def test_remove_ancillary_info(self):
        """Test case for remove_ancillary_info

        """
        pass

    def test_revert_actual_start_date(self):
        """Test case for revert_actual_start_date

        """
        pass

    def test_revert_actual_stop_date(self):
        """Test case for revert_actual_stop_date

        """
        pass

    def test_subsume_site(self):
        """Test case for subsume_site

        """
        pass

    def test_unlink_section81_from_permit(self):
        """Test case for unlink_section81_from_permit

        """
        pass

    def test_update_activity(self):
        """Test case for update_activity

        """
        pass

    def test_update_actual_start_date(self):
        """Test case for update_actual_start_date

        """
        pass

    def test_update_actual_stop_date(self):
        """Test case for update_actual_stop_date

        """
        pass

    def test_update_assessment_status(self):
        """Test case for update_assessment_status

        """
        pass

    def test_update_current_traffic_management_type(self):
        """Test case for update_current_traffic_management_type

        """
        pass

    def test_update_excavation_carried_out(self):
        """Test case for update_excavation_carried_out

        """
        pass

    def test_update_final_reinstatement(self):
        """Test case for update_final_reinstatement

        """
        pass

    def test_update_forward_plan(self):
        """Test case for update_forward_plan

        """
        pass

    def test_update_fpn_status(self):
        """Test case for update_fpn_status

        """
        pass

    def test_update_geographical_area(self):
        """Test case for update_geographical_area

        """
        pass

    def test_update_inspection_outcome_status(self):
        """Test case for update_inspection_outcome_status

        """
        pass

    def test_update_non_compliance_status(self):
        """Test case for update_non_compliance_status

        """
        pass

    def test_update_permit_alteration_status(self):
        """Test case for update_permit_alteration_status

        """
        pass

    def test_update_permit_discount(self):
        """Test case for update_permit_discount

        """
        pass

    def test_update_permit_duration_challenge_non_acceptance_response(self):
        """Test case for update_permit_duration_challenge_non_acceptance_response

        """
        pass

    def test_update_permit_duration_challenge_review(self):
        """Test case for update_permit_duration_challenge_review

        """
        pass

    def test_update_permit_lane_rental_assessment(self):
        """Test case for update_permit_lane_rental_assessment

        """
        pass

    def test_update_permit_status(self):
        """Test case for update_permit_status

        """
        pass

    def test_update_section58_status(self):
        """Test case for update_section58_status

        """
        pass

    def test_update_section74_ha_status(self):
        """Test case for update_section74_ha_status

        """
        pass

    def test_update_section74_promoter_status(self):
        """Test case for update_section74_promoter_status

        """
        pass

    def test_update_section81_status(self):
        """Test case for update_section81_status

        """
        pass

    def test_upload_file(self):
        """Test case for upload_file

        """
        pass

    def test_withdraw_inspection(self):
        """Test case for withdraw_inspection

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Section74UpdateHAStatusRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'status': 'Section74HAStatus',
        'site_cleared_date': 'datetime',
        'additional_details': 'str',
        'number_of_days_overrun': 'float',
        'draft_invoice_amount': 'float',
        'draft_invoice_reference': 'str',
        'final_agreed_amount': 'float',
        'invoice_reference': 'str',
        'reason_for_dispute': 'str'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'status': 'status',
        'site_cleared_date': 'site_cleared_date',
        'additional_details': 'additional_details',
        'number_of_days_overrun': 'number_of_days_overrun',
        'draft_invoice_amount': 'draft_invoice_amount',
        'draft_invoice_reference': 'draft_invoice_reference',
        'final_agreed_amount': 'final_agreed_amount',
        'invoice_reference': 'invoice_reference',
        'reason_for_dispute': 'reason_for_dispute'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, status=None, site_cleared_date=None, additional_details=None, number_of_days_overrun=None, draft_invoice_amount=None, draft_invoice_reference=None, final_agreed_amount=None, invoice_reference=None, reason_for_dispute=None):  # noqa: E501
        """Section74UpdateHAStatusRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._status = None
        self._site_cleared_date = None
        self._additional_details = None
        self._number_of_days_overrun = None
        self._draft_invoice_amount = None
        self._draft_invoice_reference = None
        self._final_agreed_amount = None
        self._invoice_reference = None
        self._reason_for_dispute = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.status = status
        if site_cleared_date is not None:
            self.site_cleared_date = site_cleared_date
        if additional_details is not None:
            self.additional_details = additional_details
        if number_of_days_overrun is not None:
            self.number_of_days_overrun = number_of_days_overrun
        if draft_invoice_amount is not None:
            self.draft_invoice_amount = draft_invoice_amount
        if draft_invoice_reference is not None:
            self.draft_invoice_reference = draft_invoice_reference
        if final_agreed_amount is not None:
            self.final_agreed_amount = final_agreed_amount
        if invoice_reference is not None:
            self.invoice_reference = invoice_reference
        if reason_for_dispute is not None:
            self.reason_for_dispute = reason_for_dispute

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this Section74UpdateHAStatusRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this Section74UpdateHAStatusRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this Section74UpdateHAStatusRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this Section74UpdateHAStatusRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def status(self):
        """Gets the status of this Section74UpdateHAStatusRequest.  # noqa: E501


        :return: The status of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: Section74HAStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Section74UpdateHAStatusRequest.


        :param status: The status of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: Section74HAStatus
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def site_cleared_date(self):
        """Gets the site_cleared_date of this Section74UpdateHAStatusRequest.  # noqa: E501

        Required when status is charges_ended Date must be today or a date in the past  # noqa: E501

        :return: The site_cleared_date of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._site_cleared_date

    @site_cleared_date.setter
    def site_cleared_date(self, site_cleared_date):
        """Sets the site_cleared_date of this Section74UpdateHAStatusRequest.

        Required when status is charges_ended Date must be today or a date in the past  # noqa: E501

        :param site_cleared_date: The site_cleared_date of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: datetime
        """

        self._site_cleared_date = site_cleared_date

    @property
    def additional_details(self):
        """Gets the additional_details of this Section74UpdateHAStatusRequest.  # noqa: E501

        Required when status is status is withdrawn Max length 500 characters  # noqa: E501

        :return: The additional_details of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._additional_details

    @additional_details.setter
    def additional_details(self, additional_details):
        """Sets the additional_details of this Section74UpdateHAStatusRequest.

        Required when status is status is withdrawn Max length 500 characters  # noqa: E501

        :param additional_details: The additional_details of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: str
        """

        self._additional_details = additional_details

    @property
    def number_of_days_overrun(self):
        """Gets the number_of_days_overrun of this Section74UpdateHAStatusRequest.  # noqa: E501

        Required when status is draft_invoice_issued or resolved Must be a positive whole number  # noqa: E501

        :return: The number_of_days_overrun of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: float
        """
        return self._number_of_days_overrun

    @number_of_days_overrun.setter
    def number_of_days_overrun(self, number_of_days_overrun):
        """Sets the number_of_days_overrun of this Section74UpdateHAStatusRequest.

        Required when status is draft_invoice_issued or resolved Must be a positive whole number  # noqa: E501

        :param number_of_days_overrun: The number_of_days_overrun of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: float
        """

        self._number_of_days_overrun = number_of_days_overrun

    @property
    def draft_invoice_amount(self):
        """Gets the draft_invoice_amount of this Section74UpdateHAStatusRequest.  # noqa: E501

        Required when status is draft_invoice_issued. Must be positive number. Can contain decimals to two decimal places.  # noqa: E501

        :return: The draft_invoice_amount of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: float
        """
        return self._draft_invoice_amount

    @draft_invoice_amount.setter
    def draft_invoice_amount(self, draft_invoice_amount):
        """Sets the draft_invoice_amount of this Section74UpdateHAStatusRequest.

        Required when status is draft_invoice_issued. Must be positive number. Can contain decimals to two decimal places.  # noqa: E501

        :param draft_invoice_amount: The draft_invoice_amount of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: float
        """

        self._draft_invoice_amount = draft_invoice_amount

    @property
    def draft_invoice_reference(self):
        """Gets the draft_invoice_reference of this Section74UpdateHAStatusRequest.  # noqa: E501

        Optional. Valid when status is draft_invoice_issued. Max length 100 characters  # noqa: E501

        :return: The draft_invoice_reference of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._draft_invoice_reference

    @draft_invoice_reference.setter
    def draft_invoice_reference(self, draft_invoice_reference):
        """Sets the draft_invoice_reference of this Section74UpdateHAStatusRequest.

        Optional. Valid when status is draft_invoice_issued. Max length 100 characters  # noqa: E501

        :param draft_invoice_reference: The draft_invoice_reference of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: str
        """

        self._draft_invoice_reference = draft_invoice_reference

    @property
    def final_agreed_amount(self):
        """Gets the final_agreed_amount of this Section74UpdateHAStatusRequest.  # noqa: E501

        Required when status is resolved. Must be positive number. Can contain decimals to two decimal places.  # noqa: E501

        :return: The final_agreed_amount of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: float
        """
        return self._final_agreed_amount

    @final_agreed_amount.setter
    def final_agreed_amount(self, final_agreed_amount):
        """Sets the final_agreed_amount of this Section74UpdateHAStatusRequest.

        Required when status is resolved. Must be positive number. Can contain decimals to two decimal places.  # noqa: E501

        :param final_agreed_amount: The final_agreed_amount of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: float
        """

        self._final_agreed_amount = final_agreed_amount

    @property
    def invoice_reference(self):
        """Gets the invoice_reference of this Section74UpdateHAStatusRequest.  # noqa: E501

        Optional. Valid when status is resolved. Max length 100 characters  # noqa: E501

        :return: The invoice_reference of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._invoice_reference

    @invoice_reference.setter
    def invoice_reference(self, invoice_reference):
        """Sets the invoice_reference of this Section74UpdateHAStatusRequest.

        Optional. Valid when status is resolved. Max length 100 characters  # noqa: E501

        :param invoice_reference: The invoice_reference of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: str
        """

        self._invoice_reference = invoice_reference

    @property
    def reason_for_dispute(self):
        """Gets the reason_for_dispute of this Section74UpdateHAStatusRequest.  # noqa: E501

        Required when status is warning_disputed. Max length 500 characters  # noqa: E501

        :return: The reason_for_dispute of this Section74UpdateHAStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._reason_for_dispute

    @reason_for_dispute.setter
    def reason_for_dispute(self, reason_for_dispute):
        """Sets the reason_for_dispute of this Section74UpdateHAStatusRequest.

        Required when status is warning_disputed. Max length 500 characters  # noqa: E501

        :param reason_for_dispute: The reason_for_dispute of this Section74UpdateHAStatusRequest.  # noqa: E501
        :type: str
        """

        self._reason_for_dispute = reason_for_dispute

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Section74UpdateHAStatusRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Section74UpdateHAStatusRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
